@@ -156,16 +156,16 @@ function fetchRemote (p, u, co, origUrl, cb) {
 
       if (process.platform === "win32") {
         log.silly("verifyOwnership", "skipping for windows")
-        resolveHead()
+        resolveHead(p, u, co, origUrl, cb)
       }
       else {
-        getGitDir(function(er, cs) {
+        getGitDir(function (er, cs) {
           if (er) {
             log.error("Could not get cache stat")
             return cb(er)
           }
 
-          chownr(p, cs.uid, cs.gid, function(er) {
+          chownr(p, cs.uid, cs.gid, function (er) {
             if (er) {
               log.error("Failed to change folder ownership under npm cache for %s", p)
               return cb(er)
