@@ -228,8 +228,7 @@ function gunzTarPerm (tarball, target, dMode, fMode, uid, gid, cb_) {
             cb(er)
           })
           .on("close", cb)
-      } else if (c.toString().match(/^package\//) ||
-                 c.toString().match(/^pax_global_header/)) {
+      } else if (hasTarHeader(c)) {
         // naked tar
         fst
           .pipe(tar.Extract(extractOpts))
@@ -273,3 +272,19 @@ function gunzTarPerm (tarball, target, dMode, fMode, uid, gid, cb_) {
       fst.emit("data", c)
     })
 }
+
+function hasTarHeader (c) {
+  return c[257] === 0x75 && // tar archives have 7573746172 at position
+         c[258] === 0x73 && // 257 and 003030 or 202000 at position 262
+         c[259] === 0x74 &&
+         c[260] === 0x61 &&
+         c[261] === 0x72 &&
+
+       ((c[262] === 0x00 &&
+         c[263] === 0x30 &&
+         c[264] === 0x30) ||
+
+        (c[262] === 0x20 &&
+         c[263] === 0x20 &&
+         c[264] === 0x00))
+}
